# frozen_string_literal: true

Ramverk::Cli::Command.class_eval do
  desc "console", "Starts an interactive console session"
  def console
    puts "Loading #{env} environment..."

    # Clear ARGV so IRB dont parse it
    ARGV.shift until ARGV.empty?

    # Add reload! helper method to console
    TOPLEVEL_BINDING.eval("self").__send__(:include, Ramverk::Console::CodeReloading)

    require File.expand_path("config/boot", Dir.pwd)

    # Avoid "irb: warn: can't alias context from irb_context."
    RSpec.configuration.disable_monkey_patching! if defined?(RSpec)

    require "irb"
    IRB.start
  end
end

module Ramverk
  class Console
    module CodeReloading
      # @private
      def reload!
        puts 'Reloading...'
        Ramverk.configuration.autoload_loader.reload
      end
    end
  end
end
