# frozen_string_literal: true

Ramverk::Cli::Command.class_eval do
  desc "new PROJECT_NAME", "Generates a new project structure"
  def new(project_name)
    project_name = escape(project_name)
    project_name = Ramverk::String.underscore(project_name)
    project_namespace = Ramverk::String.classify(project_name)

    config = {
      project_name: project_name,
      project_namespace: project_namespace
    }

    root = Pathname.new(Dir.pwd).join(project_name)

    template "new/.gitignore.tt", root.join(".gitignore"), config
    template "new/Gemfile.tt", root.join("Gemfile"), config
    template "new/Rakefile.tt", root.join("Rakefile"), config
    template "new/config.ru.tt", root.join("config.ru"), config
    template "new/.env.example.tt", root.join(".env.example"), config
    template "new/.env.test.tt", root.join(".env.test"), config
    template "new/.env.development.tt", root.join(".env.development"), config

    template "new/lib/project.rb.tt", root.join("lib", "#{project_name}.rb"), config
    create_file root.join("lib", project_name, ".gitkeep")

    template "new/config/environment.rb.tt", root.join("config", "environment.rb"), config
    template "new/config/boot.rb.tt", root.join("config", "boot.rb"), config

    template "new/spec/spec_helper.rb.tt", root.join("spec", "spec_helper.rb"), config
    template "new/spec/lib/project_spec.rb.tt", root.join("spec", "lib", "#{project_name}_spec.rb"), config
    create_file root.join("spec", "support", ".gitkeep")
  end
end
