# frozen_string_literal: true

require "rack"

Ramverk::Cli::Command.class_eval do
  desc "server", "Starts the development server"
  method_option :port, type: :numeric, aliases: "-p", default: 3000
  def server
    environment = ENV["APP_ENV"] || ENV["RACK_ENV"] || "development"

    Ramverk::Server.new(
      config: "config.ru",
      Host: "0.0.0.0",
      Port: options[:port],
      AccessLog: [],
      environment: environment
    ).start
  end
end

module Ramverk
  class Server < Rack::Server
    def middleware
      mw = ::Hash.new { |e, m| e[m] = [] }
      mw["development"].concat([::Rack::ShowExceptions])
      mw
    end
  end
end
