# frozen_string_literal: true

module Ramverk
  class Configuration
    # Module for creating configuration items on the fly.
    module DynamicGroups
      # @private
      def method_missing(meth, *args, &block)
        return super unless meth.to_s.end_with?("=")

        key = meth.to_s.sub("=", "")
        dynamic_groups[key] = args.first

        define_singleton_method(key) { dynamic_groups[key] }
      end

      # @private
      # :nocov:
      def respond_to_missing?(name, include_private = false)
        super
      end
      # :nocov:

      # @private
      def freeze
        dynamic_groups.freeze
        dynamic_groups.each_value(&:freeze)

        super
      end

      private

      # @private
      def dynamic_groups
        @dynamic_groups ||= {}
      end
    end
  end
end
