# frozen_string_literal: true

module Ramverk
  # @private
  class Resolver
    # @private
    def initialize(apps)
      @apps = apps
    end

    # @private
    def call(env)
      path = env["PATH_INFO"]

      apps.each do |app_name, (app, pattern, host)|
        next if host && !host.match?(host(env))
        next unless pattern.peek(path)

        env["ramverk.application"] = app_name.to_s

        return app.call(env)
      end

      NOT_FOUND_RESPONSE
    end

    private

    # @private
    attr_reader :apps

    # @private
    def host(env)
      env["ramverk.parsed_host"] ||= begin
        if (forwarded = env["HTTP_X_FORWARDED_HOST"])
          forwarded.split(/,\s?/).last
        else
          env["HTTP_HOST"] || env["SERVER_NAME"] || env["SERVER_ADDR"]
        end
      end
    end

    # @private
    NOT_FOUND_RESPONSE = [404, { "X-Cascade" => "pass" }, ["Not Found"]].freeze
    private_constant :NOT_FOUND_RESPONSE
  end
end
